pub trait CrashEvent: Sync + Send {
// Required method
fn on_crash(&self, minidump_path: PathBuf);
}Expand description
Trait used by the crash handler to notify the implementor that a crash was captured, providing the full path on disk to that minidump.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".